# test_rezka_scraper.py

import aiohttp
from bs4 import BeautifulSoup

class RezkaScraper:
    def __init__(self):
        self.base_url = "https://rezka.ag"
        self.headers = {
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.82 Safari/537.36"
        }

    async def search_rezka(self, name):
        search_url = f"{self.base_url}/search/?do=search&subaction=search&q={name}"
        try:
            async with aiohttp.ClientSession() as session:
                async with session.get(search_url, headers=self.headers) as response:
                    if response.status == 200:
                        text = await response.text()
                        soup = BeautifulSoup(text, "html.parser")
                        results = soup.find_all("div", class_="b-content__inline_item")
                        for result in results:
                            title_tag = result.find("div", class_="b-content__inline_item-link").find("a")
                            if title_tag:
                                title = title_tag.text.strip()
                                link = title_tag["href"]
                                if name.lower() in title.lower():
                                    return title, link
                        return None, None
                    else:
                        print("Ошибка: Не удалось выполнить поиск. Код статуса:", response.status)
                        return None, None
        except aiohttp.ClientError as e:
            print("Ошибка соединения с сервером:", str(e))
        except Exception as e:
            print("Произошла ошибка при обработке поиска:", str(e))
        return None, None

    async def search_anime(self, page=1):
        return await self._search_category("animation", page)

    async def search_movies(self, page=1):
        return await self._search_category("films", page)

    async def search_series(self, page=1):
        return await self._search_category("series", page)

    async def search_cartoons(self, page=1):
        return await self._search_category("cartoons", page)

    async def _search_category(self, category, page):
        url = f"{self.base_url}/{category}/page/{page}/"
        try:
            async with aiohttp.ClientSession() as session:
                async with session.get(url, headers=self.headers) as response:
                    if response.status == 200:
                        html = await response.text()
                        soup = BeautifulSoup(html, "html.parser")
                        results = soup.find_all("div", class_="b-content__inline_item")
                        matches = []
                        for result in results:
                            title_tag = result.find("div", class_="b-content__inline_item-link").find("a")
                            if title_tag:
                                title = title_tag.text.strip()
                                link = title_tag["href"]
                                matches.append((title, link))
                        return matches
                    else:
                        print("Ошибка: Не удалось загрузить категорию. Код статуса:", response.status)
                        return None
        except aiohttp.ClientError as e:
            print("Ошибка соединения с сервером:", str(e))
        except Exception as e:
            print("Произошла ошибка при обработке категории:", str(e))
        return None



# rezka_scraper.py

import aiohttp
from bs4 import BeautifulSoup
from fake_useragent import UserAgent


class RezkaScraper:
    def __init__(self):
        self.base_url = "https://rezka.ag"
        self.agent = UserAgent()
    def _get_headers(self):
        return {"User-Agent": self.agent.random}


    async def search_rezka(self, name, images=False):
        search_url = f"{self.base_url}/search/?do=search&subaction=search&q={name}"
        try:
            async with aiohttp.ClientSession() as session:
                async with session.get(search_url, headers=self._get_headers()) as response:
                    if response.status != 200:
                        raise Exception(f"HTTP ошибка: {response.status} при запросе: {search_url}")
                    text = await response.text()
                    soup = BeautifulSoup(text, "html.parser")
                    results = soup.find_all("div", class_="b-content__inline_item")
                    if not results:
                        return (None, None, None) if images else (None, None)
                    for result in results:
                        title_tag = result.find("div", class_="b-content__inline_item-link").find("a")
                        if not title_tag:
                            continue
                        title = title_tag.text.strip()
                        link = title_tag["href"]
                        image_url = None
                        if images:
                            image_tag = result.find("div", class_="b-content__inline_item-cover").find("img")
                            image_url = image_tag["src"] if image_tag else None
                        if name.lower() in title.lower():
                            return (title, link, image_url) if images else (title, link)
                    return (None, None, None) if images else (None, None)
        except aiohttp.ClientError as e:
            raise Exception(f"Ошибка подключения: {e}\n\nСообщить об ошибке: https://t.me/OFFpolice2077")
        except Exception as e:
            raise Exception(f"Ошибка обработки данных: {e}\n\nСообщить об ошибке: https://t.me/OFFpolice2077")


    async def search_anime(self, page=1):
        return await self._search_category("animation", page)

    async def search_movies(self, page=1):
        return await self._search_category("films", page)

    async def search_series(self, page=1):
        return await self._search_category("series", page)

    async def search_cartoons(self, page=1):
        return await self._search_category("cartoons", page)


    async def _search_category(self, category, page):
        url = f"{self.base_url}/{category}/page/{page}/"
        try:
            async with aiohttp.ClientSession() as session:
                async with session.get(url, headers=self._get_headers()) as response:
                    if response.status != 200:
                        raise Exception(f"HTTP ошибка: {response.status} при запросе: {url}")
                    html = await response.text()
                    soup = BeautifulSoup(html, "html.parser")
                    results = soup.find_all("div", class_="b-content__inline_item")
                    if not results:
                        return None
                    matches = []
                    for result in results:
                        title_tag = result.find("div", class_="b-content__inline_item-link").find("a")
                        if title_tag:
                            title = title_tag.text.strip()
                            link = title_tag["href"]
                            matches.append((title, link))
                    return matches
        except aiohttp.ClientError as e:
            raise Exception(f"Ошибка подключения: {e}\n\nСообщить об ошибке: https://t.me/OFFpolice2077")
        except Exception as e:
            raise Exception(f"Ошибка обработки данных: {e}\n\nСообщить об ошибке: https://t.me/OFFpolice2077")



# setup.py

import pathlib
from setuptools import setup, find_packages


here = pathlib.Path(__file__).parent.resolve()
long_description = (here / "README.md").read_text(encoding="utf-8")


setup(
    name='rezka_scraper',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[
        'aiohttp==3.11.11',
        'beautifulsoup4==4.12.3',
        'fake-useragent==2.0.3',
    ],
    python_requires='>=3.10',
    description='RezkaScraper — это мини библиотека на Python для асинхронного поиска контента (аниме, фильмов, сериалов и мультфильмов) на сайте Rezka.ag',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='OFFpolice',
    author_email='offpolice2077@gmail.com',
    url='https://github.com/OFFpolice/rezka_scraper',
    classifiers=[
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
